// Deprecate mixin
//
// This mixin can be used to deprecate mixins or functions.
// `@enable-deprecation-messages` is a global variable, `@ignore-warning` is a variable that can be passed to
// some deprecated mixins to suppress the warning (for example if the mixin is still be used in the current version of Bootstrap)
#deprecate(@name, @deprecate-version, @remove-version, @ignore-warning: false) {
	& when not (@enable-deprecation-messages = false) and (@ignore-warning = false) {
		// LESS PORT: Wording this a little differently to clarify that the version values apply to
		// Boostrap and not Bootstrap-Less-Port.
		warn("@{name} has been deprecated as of Bootstrap @{deprecate-version}. It will be removed entirely in Bootstrap @{remove-version}.");
	}
}
