#float-left() {
	float: left !important;
	#deprecate("The `#float-left()` mixin", "v4.3.0", "v5");
}
#float-right() {
	float: right !important;
	#deprecate("The `#float-right()` mixin", "v4.3.0", "v5");
}
#float-none() {
	float: none !important;
	#deprecate("The `#float-none()` mixin", "v4.3.0", "v5");
}
